modelInt_predict: Prediction interval for a fitted 'merMod' object. See 'lmer',...

Description Usage Arguments Details Value

View source: R/modelInt_predict.R

Description

This function uses bootMer to bootstrap a mixed model and calculate prediction intervals.

Usage

1
2
modelInt_predict(model, df, n_sim = 100, prob = 0.95, cluster = NULL,
  cluster_name = NULL, ...)

Arguments

model

fitted merMod object

df

data frame with new combination of fixed effect values to generate prediction

n_sim

number of bootstrap simulation

prob

probability for the predicted interval

cluster

logical. TRUE / FALSE for whether to use parallele computing. See bootMer

cluster_name

if cluster = TRUE, a user-defined cluster name

...

see bootMer for more argument options

Details

See bootMer and boot for further details. information about the presence/absence of the incubating individual in the nest.

Value

Data frame with prediction interval


PabloCapilla/WeaverTools documentation built on Nov. 22, 2019, 5 a.m.