wbsw_gc: Calculate group composition using, the most famous, Careers...

Description Usage Arguments Value

Description

This function takes time interval and calculates group composition.

Usage

1
2
3
wbsw_gc(Careers, career_startDate, career_endDate, career_birdID,
  career_season, season, group, interval, all_birds, maturationTime,
  time_steps)

Arguments

Careers

name of the sparrow weaver project careers table loaded in R

career_startDate

character type. Name of the column specifying residence start times in Careers table, for GC calculations

career_endDate

character type. Name of the column specifying residence end times in Careers table, for GC calculations

career_birdID

character type. Name of the column specifying bird ID in Careers table. Please, note that this name has to be common across the Careers and All Birds tables

career_season

character type. Name of the column specifying season in Careers table

season

for a specific time interval, define the season

group

group name for group composition calculation

interval

vector of length 2. Each element follwing format = Y-m-d. The first element corresponds to the start date of the interval

all_birds

name of the All Birds table loaded in R

maturationTime

Number of days a bird is considered as a fledgling after hatching. It serves to count birds inthe first days of life

time_steps

number of intervals to divide period of gc calculations

Value

A vector with the following information


PabloCapilla/WeaverTools documentation built on Nov. 22, 2019, 5 a.m.